
/*
Copyright 2007 Kim A. Brandt <kimabrandt@gmx.de>

This file is part of prefswitch.

Prefswitch is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

Prefswitch is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with prefswitch; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

function ProfileDialog()
{
	this.control = null;
	this.listbox = null;
	this.dialogheader = null;
	this.vbox = null;
	this.listitem = null;
	this.profile = null;

	this.click = function(tSwitch, tState)
	{
		if(this.profile == null) return;
//		this.profile.setFeature(menuitem.getAttribute("id"), menuitem["value"]);
		this.profile.setFeature(tSwitch.getID(), tState.getID());
	};

	this.newProfile = function()
	{
		this.profile = new Profile("New Profile");
		var listitem = this.listbox.appendItem(this.profile.getName());
		listitem.p = this.profile;
		this.listbox.selectedIndex = this.listbox.getRowCount() - 1;
		this.refreshProfiles();
		if(!this.renameProfile())
		{
			this.listbox.removeItemAt(this.listbox.selectedIndex);
			if(this.listbox.getRowCount() > 0) this.listbox.selectedIndex = 0;
			else this.refreshProfiles();
		}
	};

	this.renameProfile = function()
	{
		if(this.profile == null) return false;
		var name = prompt("Enter name of profile:", this.profile.getName());
		if(name == null || name == "") return false;
		this.profile.setName(name);
		this.refreshProfiles();
		return true;
	};

	this.removeProfile = function()
	{
		if(this.listbox.selectedIndex < 0) return;
		this.listbox.removeItemAt(this.listbox.selectedIndex);
		if(this.listbox.getRowCount() > 0) this.listbox.selectedIndex = 0;
	};

	this.load = function()
	{
		if("arguments" in window && window.arguments.length > 0) this.control = window.arguments[0];
		else this.control = new Control();
		this.listbox = document.getElementById("listbox");
		this.dialogheader = document.getElementById("dialogheader");
		this.vbox = document.getElementById("vbox");
		this.listbox.addEventListener("select", this, false);
		this.loadMenulists();
		this.loadProfiles();
		if(this.listbox.getRowCount() > 0) this.listbox.selectedIndex = 0;
	};

	this.handleEvent = function(event)
	{
/*		switch(event.type)
		{
			case "select":*/ this.refreshProfiles(); //break;
//		}
	};

	this.loadMenulists = function()
	{
		var aSwitch = this.control.getSwitches();
		var tSwitch = aSwitch.shift();
		while(tSwitch)
		{
			var hbox = document.createElement("hbox");
			hbox.setAttribute("align", "center");
			var label = document.createElement("label");
			label.setAttribute("value", tSwitch.getName() + ":");
			hbox.appendChild(label);
			var menulist = document.createElement("menulist");
			menulist.setAttribute("id", tSwitch.getID());
			menulist.sw = tSwitch;
			menulist.setAttribute("label", tSwitch.getName());
			var menupopup = document.createElement("menupopup");
			var aState = tSwitch.getStates();
			var tState = aState.shift();
			while(tState)
			{
				var menuitem = document.createElement("menuitem");
//				menuitem.setAttribute("name", tSwitch.getName());
				menuitem.setAttribute("label", tState.getName());
/*				menuitem.setAttribute("value", tState.getID());*/
				menuitem.sw = tSwitch;
				menuitem.st = tState;
				menuitem.setAttribute("oncommand", "profileDialog.click(this.sw, this.st)");
				menupopup.appendChild(menuitem);
				tState = aState.shift();
			}
			menulist.appendChild(menupopup);
			hbox.appendChild(menulist);
			this.vbox.appendChild(hbox);
			tSwitch = aSwitch.shift();
		}
	};

	this.loadProfiles = function()
	{
		var aProfile = this.control.getProfiles();
		for(var i=0; i<aProfile.length; i++)
		{
			var tProfile = aProfile[i];
			var listitem = this.listbox.appendItem(tProfile.getName());
			listitem.p = tProfile;
		}
		if(this.listbox.getRowCount() > 0 && this.listbox.selectedIndex < 0) this.listbox.selectedIndex = 0;
	};

	this.refreshProfiles = function()
	{
		if(this.listbox.selectedIndex < 0)
		{
			this.listitem = null;
			this.profile = null;
			this.dialogheader.setAttribute("title", "");
		}
		else
		{
			this.listitem = this.listbox.getSelectedItem(0);
			if(this.listitem == null) return;
			this.profile = this.listitem.p;
			if(this.profile == null) return;
			
			this.listitem.setAttribute("label", this.profile.getName());
			this.dialogheader.setAttribute("title", this.profile.getName());
			// SELECT MENUITEMS
			var aMenulist = document.getElementsByTagName("menulist");
			for(var i=0; i<aMenulist.length; i++)
			{
				var menupopup = aMenulist[i].firstChild;
				var menuitem = menupopup.firstChild;
				var feature = this.profile.getFeature(aMenulist[i].sw.getID());
				if(feature)
				{
					while(menuitem)
					{
						if(feature == menuitem.st.getID())
						{
							aMenulist[i].selectedItem = menuitem;
							break;
						}
						menuitem = menuitem.nextSibling;
					}
				}
				else
				{
					aMenulist[i].selectedIndex = 0;
					this.profile.setFeature(menuitem.sw.getID(), menuitem.st.getID());
				}
			}
		}
	};

	this.accept = function()
	{
		var data = this.generateXml();
		this.control.saveProfiles(data);
		this.control.update(UPDATE_PROFILES);
	};

	this.generateXml = function()
	{
		var sResult = "" +
"<?xml version=\"1.0\" encoding=\"" + CHARSET + "\"?>\n" +
"<prefswitch>\n";
		for(var i=0; i<this.listbox.getRowCount(); i++)
		{
			var tProfile = this.listbox.getItemAtIndex(i).p;
			if(tProfile == null) continue;
			sResult += "" +
"	<profile name=\"" + this.control.encode(tProfile.getName()) + "\">\n";
			for(var key in tProfile.getFeatures())
			{
				sResult += "" +
"		<feature key=\"" + key + "\" " +
			"value=\"" + tProfile.getFeature(key) + "\" />\n";
			}
			sResult += "" +
"	</profile>\n";
		}
		sResult += "" +
"</prefswitch>\n";
		return sResult;
	};
}

var profileDialog = new ProfileDialog();
